@@ -71,7 +71,8 @@ class LikeFile:
     def read(self, length = -1):
         """Build up self.outbuf, return first length bytes"""
         if length == -1:
-            while not self.eof: self._add_to_outbuf_once()
+            while not self.eof:
+                self._add_to_outbuf_once()
             real_len = len(self.outbuf)
         else:
             while not self.eof and len(self.outbuf) < length:
@@ -84,9 +85,12 @@ class LikeFile:
 
     def _add_to_outbuf_once(self):
         """Add one cycle's worth of output to self.outbuf"""
-        if not self.infile_eof: self._add_to_inbuf()
-        try: self.eof, len_inbuf_read, cycle_out = self.maker.cycle(self.inbuf)
-        except _librsync.librsyncError, e: raise librsyncError(str(e))
+        if not self.infile_eof:
+            self._add_to_inbuf()
+        try:
+            self.eof, len_inbuf_read, cycle_out = self.maker.cycle(self.inbuf)
+        except _librsync.librsyncError, e:
+            raise librsyncError(str(e))
         self.inbuf = self.inbuf[len_inbuf_read:]
         self.outbuf.fromstring(cycle_out)
 
@@ -104,7 +108,8 @@ class LikeFile:
 
     def close(self):
         """Close infile"""
-        if not self.infile_closed: assert not self.infile.close()
+        if not self.infile_closed:
+            assert not self.infile.close()
         self.closed = 1
 
 
@@ -118,8 +123,10 @@ class SigFile(LikeFile):
 
         """
         LikeFile.__init__(self, infile)
-        try: self.maker = _librsync.new_sigmaker(blocksize)
-        except _librsync.librsyncError, e: raise librsyncError(str(e))
+        try:
+            self.maker = _librsync.new_sigmaker(blocksize)
+        except _librsync.librsyncError, e:
+            raise librsyncError(str(e))
 
 class DeltaFile(LikeFile):
     """File-like object which incrementally generates a librsync delta"""
@@ -132,13 +139,16 @@ class DeltaFile(LikeFile):
 
         """
         LikeFile.__init__(self, new_file)
-        if type(signature) is types.StringType: sig_string = signature
+        if type(signature) is types.StringType:
+            sig_string = signature
         else:
             self.check_file(signature)
             sig_string = signature.read()
             assert not signature.close()
-        try: self.maker = _librsync.new_deltamaker(sig_string)
-        except _librsync.librsyncError, e: raise librsyncError(str(e))
+        try:
+            self.maker = _librsync.new_deltamaker(sig_string)
+        except _librsync.librsyncError, e:
+            raise librsyncError(str(e))
 
 
 class PatchedFile(LikeFile):
@@ -154,8 +164,10 @@ class PatchedFile(LikeFile):
         LikeFile.__init__(self, delta_file)
         if type(basis_file) is not types.FileType:
             raise TypeError("basis_file must be a (true) file")
-        try: self.maker = _librsync.new_patchmaker(basis_file)
-        except _librsync.librsyncError, e: raise librsyncError(str(e))      
+        try:
+            self.maker = _librsync.new_patchmaker(basis_file)
+        except _librsync.librsyncError, e:
+            raise librsyncError(str(e))      
 
 
 class SigGenerator:
@@ -167,8 +179,10 @@ class SigGenerator:
     """
     def __init__(self, blocksize = _librsync.RS_DEFAULT_BLOCK_LEN):
         """Return new signature instance"""
-        try: self.sig_maker = _librsync.new_sigmaker(blocksize)
-        except _librsync.librsyncError, e: raise librsyncError(str(e))
+        try:
+            self.sig_maker = _librsync.new_sigmaker(blocksize)
+        except _librsync.librsyncError, e:
+            raise librsyncError(str(e))
         self.gotsig = None
         self.buffer = ""
         self.sig_string = ""
@@ -184,14 +198,17 @@ class SigGenerator:
 
     def process_buffer(self):
         """Run self.buffer through sig_maker, add to self.sig_string"""
-        try: eof, len_buf_read, cycle_out = self.sig_maker.cycle(self.buffer)
-        except _librsync.librsyncError, e: raise librsyncError(str(e))
+        try:
+            eof, len_buf_read, cycle_out = self.sig_maker.cycle(self.buffer)
+        except _librsync.librsyncError, e:
+            raise librsyncError(str(e))
         self.buffer = self.buffer[len_buf_read:]
         self.sig_string += cycle_out
         return eof
 
     def getsig(self):
         """Return signature over given data"""
-        while not self.process_buffer(): pass # keep running until eof
+        while not self.process_buffer():
+            pass # keep running until eof
         return self.sig_string
 
